==> haskell-cookie-0.4.3-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cookie.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cookie
version: 0.4.3
id: cookie-0.4.3-Io6uJFDZABDQfuTV3c9a1
key: cookie-0.4.3-Io6uJFDZABDQfuTV3c9a1
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/cookie
synopsis: HTTP cookie parsing and rendering
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Web.Cookie
abi: 2d34ba5e11be7edd0144b9154a654f6c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cookie-0.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/cookie-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cookie-0.4.3
hs-libraries: HScookie-0.4.3-Io6uJFDZABDQfuTV3c9a1
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9 time-1.8.0.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA=46678a76449231ad37b0ff9566dd89ca
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=a09774905d29698e6c89ba4927e5c216
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5=59d0190781dd74e9cf2161eb5998f2f1
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html: /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cookie-0.4.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cookie.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cookie
version: 0.4.4
id: cookie-0.4.4-CiS7yXa2MgeFoC1n9W9khF
key: cookie-0.4.4-CiS7yXa2MgeFoC1n9W9khF
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/cookie
synopsis: HTTP cookie parsing and rendering
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Web.Cookie
abi: ba627a20ec4f34e9374f55f1f0408367
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cookie-0.4.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/cookie-0.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cookie-0.4.4
hs-libraries: HScookie-0.4.4-CiS7yXa2MgeFoC1n9W9khF
depends:
    base-4.10.1.0 bytestring-0.10.8.2 time-1.8.0.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5=59d0190781dd74e9cf2161eb5998f2f1
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html: /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
